==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fr/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Un utilisateur a annulé une commande d’article sur le site Web',
    'a_user_requested' => 'Un utilisateur a commandé un article sur le site Web',
    'accessory_name' => 'Nom de l’accessoire :',
    'additional_notes' => 'Notes complémentaires :',
    'admin_has_created' => 'Un administrateur a créé un compte pour vous sur le site :web.',
    'asset' => 'Produit:',
    'asset_name' => 'Nom du produit:',
    'asset_requested' => 'Produit demandé',
    'asset_tag' => 'Code produit:',
    'assigned_to' => 'Affecté à',
    'best_regards' => 'Cordialement,',
    'canceled' => 'Annulé:',
    'checkin_date' => 'Date d\'association :',
    'checkout_date' => 'Date de dissociation :',
    'click_to_confirm' => 'Veuillez cliquer sur le lien suivant pour confirmer votre :web account:',
    'click_on_the_link_accessory' => 'Merci de cliquer sur le lien ci-dessous pour confirmer la bonne réception de l\'accessoire.',
    'click_on_the_link_asset' => 'Cliquez sur le lien ci-dessous pour confirmer que vous avez reçu l\'actif.',
    'Confirm_Asset_Checkin' => 'Confirmation de l\'association du matériel',
    'Confirm_Accessory_Checkin' => 'Confirmation de l\'association de l\'accessoire',
    'Confirm_accessory_delivery' => 'Confirmation de la livraison de l\'accessoire',
    'Confirm_license_delivery' => 'Confirmation de la livraison de licence',
    'Confirm_asset_delivery' => 'Confirmation de la livraison du matériel',
    'Confirm_consumable_delivery' => 'Confirmation de la livraison du consommable',
    'current_QTY' => 'Quantité actuelle',
    'Days' => 'Jours',
    'days' => 'jours',
    'expecting_checkin_date' => 'Date d\'association prévue :',
    'expires' => 'Expire le',
    'Expiring_Assets_Report' => 'Rapport d\'expiration des actifs.',
    'Expiring_Licenses_Report' => 'Rapport d\'expiration des licences.',
    'hello' => 'Bonjour',
    'hi' => 'Salut',
    'i_have_read' => 'J\'ai bien lu et approuvé les conditions d\'utilisation, et reçu cet objet.',
    'item' => 'Article :',
    'Item_Request_Canceled' => 'Demande d\'article annulée',
    'Item_Requested' => 'Demande d\'article',
    'link_to_update_password' => 'Veuillez cliquer sur le lien suivant pour confirmer votre :web account:',
    'login_first_admin' => 'Connectez-vous à votre nouvelle installation Snipe-IT en utilisant les informations d\'identification ci-dessous :',
    'login' => 'Nom d\'utilisateur:',
    'Low_Inventory_Report' => 'Rapport d’inventaire bas',
    'min_QTY' => 'Quantité minimum',
    'name' => 'Nom',
    'new_item_checked' => 'Un nouvel élément a été vérifié sous votre nom, les détails sont ci-dessous.',
    'password' => 'Mot de passe:',
    'password_reset' => 'Réinitialisation du mot de passe',

    'read_the_terms' => 'Merci de lire les conditions d\'utilisation ci-dessous.',
    'read_the_terms_and_click' => 'Merci de lire les conditions d\'utilisation ci-dessous, et cliquer sur le lien ci-dessous pour confirmer que vous avez lu                         et accepté les conditions d\'utilisation et reçu l\'équipement.',
    'requested' => 'Demandé:',
    'reset_link' => 'Votre lien pour réinitialiser le mot de passe',
    'reset_password' => 'Cliquez ici pour réinitialiser votre mot de passe:',
    'serial' => 'N° de série ',
    'supplier' => 'Fournisseur',
    'tag' => 'Étiquette',
    'test_email' => 'Email test de Snipe-IT',
    'test_mail_text' => 'Il s\'agit d\'un test du système de gestion d\'actifs Snipe-IT. Si vous avez obtenu cela, le courrier fonctionne :)',
    'the_following_item' => 'L\'élément suivant a été enregistré : ',
    'low_inventory_alert' => 'Il y a :count item qui est en dessous du minimum d\'inventaire ou qui sera bas sous peu.|Il y a :count articles qui sont en dessous du minimum d\'inventaire ou qui seront bas sous peu.',
    'assets_warrantee_alert' => 'Il y a :count actifs avec une garantie expirant dans les prochains :threshold jours.|Il y a :count actifs avec des garanties expirant dans les prochains :threshold jours.',
    'license_expiring_alert' => 'Il y a :count licence expirant dans les prochains :threshold jours.|Il y a :count licences expirant dans les prochains :threshold jours.',
    'to_reset' => 'Pour réinitialiser votre mot de passe :web, complétez ce formulaire:',
    'type' => 'Type ',
    'upcoming-audits' => 'Il y a :count matériel à venir pour un audit dans les :threshold jours.|Il y a :count matériels à venir pour un audit dans les :threshold jours.',
    'user' => 'Utilisateur',
    'username' => 'Nom d\'utilisateur',
    'welcome' => 'Bienvenue, :name',
    'welcome_to' => 'Bienvenue sur :web!',
    'your_credentials' => 'Vos identifiants Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessoire enregistré',
    'Asset_Checkin_Notification' => 'Matériel enregistré',
    'License_Checkin_Notification' => 'Licence enregistrée',
    'Expected_Checkin_Report' => 'Rapport de vérification de matériel attendu',
    'Expected_Checkin_Notification' => 'Rappel : la date limite de vérification de :name approche',
    'Expected_Checkin_Date' => 'Un matériel que vous avez emprunté doit être vérifié à nouveau le :date',
    'your_assets' => 'Voir vos matériels'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fr/mail.php <==
<?php

return [
    'a_user_canceled' => 'Un utilisateur a annulé une commande d’article sur le site Web',
    'a_user_requested' => 'Un utilisateur a commandé un article sur le site Web',
    'accessory_name' => 'Nom de l’accessoire :',
    'additional_notes' => 'Notes complémentaires :',
    'admin_has_created' => 'Un administrateur a créé un compte pour vous sur le site :web.',
    'asset' => 'Produit:',
    'asset_name' => 'Nom du produit:',
    'asset_requested' => 'Produit demandé',
    'asset_tag' => 'Numéro d\'inventaire',
    'assigned_to' => 'Affecté à',
    'best_regards' => 'Cordialement,',
    'canceled' => 'Annulé:',
    'checkin_date' => 'Date d\'association :',
    'checkout_date' => 'Date de dissociation :',
    'click_to_confirm' => 'Veuillez cliquer sur le lien suivant pour confirmer votre :web account:',
    'click_on_the_link_accessory' => 'Merci de cliquer sur le lien ci-dessous pour confirmer la bonne réception de l\'accessoire.',
    'click_on_the_link_asset' => 'Cliquez sur le lien ci-dessous pour confirmer que vous avez reçu l\'actif.',
    'Confirm_Asset_Checkin' => 'Confirmation de l\'association du matériel',
    'Confirm_Accessory_Checkin' => 'Confirmation de l\'association de l\'accessoire',
    'Confirm_accessory_delivery' => 'Confirmation de la livraison de l\'accessoire',
    'Confirm_license_delivery' => 'Confirmation de la livraison de licence',
    'Confirm_asset_delivery' => 'Confirmation de la livraison du matériel',
    'Confirm_consumable_delivery' => 'Confirmation de la livraison du consommable',
    'current_QTY' => 'Quantité actuelle',
    'Days' => 'Jours',
    'days' => 'jours',
    'expecting_checkin_date' => 'Date d\'association prévue :',
    'expires' => 'Expire le',
    'Expiring_Assets_Report' => 'Rapport d\'expiration des actifs.',
    'Expiring_Licenses_Report' => 'Rapport d\'expiration des licences.',
    'hello' => 'Bonjour',
    'hi' => 'Salut',
    'i_have_read' => 'J\'ai bien lu et approuvé les conditions d\'utilisation, et reçu cet objet.',
    'item' => 'Article :',
    'Item_Request_Canceled' => 'Demande d\'article annulée',
    'Item_Requested' => 'Demande d\'article',
    'link_to_update_password' => 'Veuillez cliquer sur le lien suivant pour confirmer votre :web account:',
    'login_first_admin' => 'Connectez-vous à votre nouvelle installation Snipe-IT en utilisant les informations d\'identification ci-dessous :',
    'login' => 'Nom d\'utilisateur:',
    'Low_Inventory_Report' => 'Rapport d’inventaire bas',
    'min_QTY' => 'Quantité minimum',
    'name' => 'Nom',
    'new_item_checked' => 'Un nouvel élément a été vérifié sous votre nom, les détails sont ci-dessous.',
    'password' => 'Mot de passe:',
    'password_reset' => 'Réinitialisation du mot de passe',

    'read_the_terms' => 'Merci de lire les conditions d\'utilisation ci-dessous.',
    'read_the_terms_and_click' => 'Merci de lire les conditions d\'utilisation ci-dessous, et cliquer sur le lien ci-dessous pour confirmer que vous avez lu                         et accepté les conditions d\'utilisation et reçu l\'équipement.',
    'requested' => 'Demandé:',
    'reset_link' => 'Votre lien pour réinitialiser le mot de passe',
    'reset_password' => 'Cliquez ici pour réinitialiser votre mot de passe:',
    'serial' => 'N° de série ',
    'supplier' => 'Fournisseur',
    'tag' => 'Étiquette',
    'test_email' => 'Email test de Snipe-IT',
    'test_mail_text' => 'Il s\'agit d\'un test du système de gestion d\'actifs Snipe-IT. Si vous avez obtenu cela, le courrier fonctionne :)',
    'the_following_item' => 'L\'élément suivant a été enregistré : ',
    'low_inventory_alert' => 'Il y a :count item qui est en dessous du minimum d\'inventaire ou qui sera bas sous peu.|Il y a :count articles qui sont en dessous du minimum d\'inventaire ou qui seront bas sous peu.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Il y a :count licence expirant dans les prochains :threshold jours.|Il y a :count licences expirant dans les prochains :threshold jours.',
    'to_reset' => 'Pour réinitialiser votre mot de passe :web, complétez ce formulaire:',
    'type' => 'Type ',
    'upcoming-audits' => 'Il y a :count matériel à venir pour un audit dans les :threshold jours.|Il y a :count matériels à venir pour un audit dans les :threshold jours.',
    'user' => 'Utilisateur',
    'username' => 'Nom d\'utilisateur',
    'welcome' => 'Bienvenue, :name',
    'welcome_to' => 'Bienvenue sur :web!',
    'your_credentials' => 'Vos identifiants Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessoire enregistré',
    'Asset_Checkin_Notification' => 'Matériel enregistré',
    'License_Checkin_Notification' => 'Licence enregistrée',
    'Expected_Checkin_Report' => 'Rapport de vérification de matériel attendu',
    'Expected_Checkin_Notification' => 'Rappel : la date limite de vérification de :name approche',
    'Expected_Checkin_Date' => 'Un matériel que vous avez emprunté doit être vérifié à nouveau le :date',
    'your_assets' => 'Voir vos matériels',
];
